@@ -12,7 +12,7 @@ from multiprocessing import Lock,Process,Queue,queues
 from datetime import datetime
 from contextlib import redirect_stdout,contextmanager
 from collections.abc import Iterable,Iterator,Generator,Sequence
-from typing import Union,Optional
+from typing import Union,Optional,TypeVar,Callable,Any
 from types import SimpleNamespace
 from pathlib import Path
 from collections import OrderedDict,defaultdict,Counter,namedtuple
@@ -86,4 +86,4 @@ def equals(a,b):
 
 
 def pv(text, verbose):
-    if verbose: print(text)
+    if verbose: print(text)
\ No newline at end of file
